from third_sdk.jd.api.rest.UnionOpenGoodsJingfenQueryRequest import UnionOpenGoodsJingfenQueryRequest
from third_sdk.jd.api.rest.UnionOpenOrderQueryRequest import UnionOpenOrderQueryRequest
from third_sdk.jd.api.rest.ServiceActivityInfoReportRequest import ServiceActivityInfoReportRequest
from third_sdk.jd.api.rest.KplOpenMigumusicCheckstatusRequest import KplOpenMigumusicCheckstatusRequest
from third_sdk.jd.api.rest.KplOpenOrderFindchildorderbyparentRequest import KplOpenOrderFindchildorderbyparentRequest
from third_sdk.jd.api.rest.KplOpenMigumusicDeliverandactivecodeRequest import KplOpenMigumusicDeliverandactivecodeRequest
from third_sdk.jd.api.rest.KplOpenPolcenterSubscribemobileRequest import KplOpenPolcenterSubscribemobileRequest
from third_sdk.jd.api.rest.KeplerSettledAftermarketApplyaftermarketRequest import KeplerSettledAftermarketApplyaftermarketRequest
from third_sdk.jd.api.rest.KplOpenJdrepairGetinfoRequest import KplOpenJdrepairGetinfoRequest
from third_sdk.jd.api.rest.MfaInnerUserUnifiedAuthenticationRequest import MfaInnerUserUnifiedAuthenticationRequest
from third_sdk.jd.api.rest.KplOpenOrderInfoQueryorderRequest import KplOpenOrderInfoQueryorderRequest
from third_sdk.jd.api.rest.KplOpenWareZhaoshangGoodsQueryRequest import KplOpenWareZhaoshangGoodsQueryRequest
from third_sdk.jd.api.rest.KplOpenPolcenterGetexpressinfoRequest import KplOpenPolcenterGetexpressinfoRequest
from third_sdk.jd.api.rest.KplOpenGetsellpriceQueryRequest import KplOpenGetsellpriceQueryRequest
from third_sdk.jd.api.rest.KplOpenItemQuerythirtydaysummaryRequest import KplOpenItemQuerythirtydaysummaryRequest
from third_sdk.jd.api.rest.KplOpenConfirmreceivedQueryRequest import KplOpenConfirmreceivedQueryRequest
from third_sdk.jd.api.rest.ProductCheckAreaLimitQueryRequest import ProductCheckAreaLimitQueryRequest
from third_sdk.jd.api.rest.MfaInnerValidateMsgCodeRequest import MfaInnerValidateMsgCodeRequest
from third_sdk.jd.api.rest.MfaInnerEliminateRiskRequest import MfaInnerEliminateRiskRequest
from third_sdk.jd.api.rest.KeplerSettledAftermarketGetbackmodeRequest import KeplerSettledAftermarketGetbackmodeRequest
from third_sdk.jd.api.rest.SearchWareRequest import SearchWareRequest
from third_sdk.jd.api.rest.MfaInnerSendCodeToMobileRequest import MfaInnerSendCodeToMobileRequest
from third_sdk.jd.api.rest.WirelessWarePriceGetRequest import WirelessWarePriceGetRequest
from third_sdk.jd.api.rest.UserGetUserInfoByOpenIdRequest import UserGetUserInfoByOpenIdRequest
from third_sdk.jd.api.rest.UnionOpenPromotionByunionidGetRequest import UnionOpenPromotionByunionidGetRequest
from third_sdk.jd.api.rest.UnionOpenPositionQueryRequest import UnionOpenPositionQueryRequest
from third_sdk.jd.api.rest.YsdkMemberApplyJsfServiceSaveMemberAndProtocolInfoRequest import YsdkMemberApplyJsfServiceSaveMemberAndProtocolInfoRequest
from third_sdk.jd.api.rest.OpenBlueInvoiceUploadRequest import OpenBlueInvoiceUploadRequest
from third_sdk.jd.api.rest.UnionOpenPositionCreateRequest import UnionOpenPositionCreateRequest
from third_sdk.jd.api.rest.KeplerSettledAftermarketSaveaftermarketRequest import KeplerSettledAftermarketSaveaftermarketRequest
from third_sdk.jd.api.rest.UnionOpenGoodsQueryRequest import UnionOpenGoodsQueryRequest
from third_sdk.jd.api.rest.KeplerSettledAftermarketGetreturnedwayRequest import KeplerSettledAftermarketGetreturnedwayRequest
from third_sdk.jd.api.rest.UnionOpenGoodsPromotiongoodsinfoQueryRequest import UnionOpenGoodsPromotiongoodsinfoQueryRequest
from third_sdk.jd.api.rest.KplOpenWeiboCartAddRequest import KplOpenWeiboCartAddRequest
from third_sdk.jd.api.rest.UnionOpenPromotionCommonGetRequest import UnionOpenPromotionCommonGetRequest
from third_sdk.jd.api.rest.UnionOpenPromotionBysubunionidGetRequest import UnionOpenPromotionBysubunionidGetRequest
from third_sdk.jd.api.rest.UnionOpenCouponQueryRequest import UnionOpenCouponQueryRequest
from third_sdk.jd.api.rest.PriceSellPriceGetRequest import PriceSellPriceGetRequest
from third_sdk.jd.api.rest.ProductStateQueryRequest import ProductStateQueryRequest
from third_sdk.jd.api.rest.ProductDetailQueryRequest import ProductDetailQueryRequest
from third_sdk.jd.api.rest.KplOpenWfpJmiwareAddWareRequest import KplOpenWfpJmiwareAddWareRequest
from third_sdk.jd.api.rest.KplOpenFalvwangRequestRequest import KplOpenFalvwangRequestRequest
from third_sdk.jd.api.rest.KplOpenTradeTencentOrderlistRequest import KplOpenTradeTencentOrderlistRequest
from third_sdk.jd.api.rest.KplOpenWfpJmiwareUpdateWareStatusRequest import KplOpenWfpJmiwareUpdateWareStatusRequest
from third_sdk.jd.api.rest.KeplerXuanpinCpsurlConvertRequest import KeplerXuanpinCpsurlConvertRequest
from third_sdk.jd.api.rest.KplOpenWfpVscLegalOrderRequest import KplOpenWfpVscLegalOrderRequest
from third_sdk.jd.api.rest.KeplerXuanpinGenclickurlBatchRequest import KeplerXuanpinGenclickurlBatchRequest
from third_sdk.jd.api.rest.JsfXbXBProductServiceQueryProductsRequest import JsfXbXBProductServiceQueryProductsRequest
from third_sdk.jd.api.rest.KplOpenWfpJmiwareEditWareRequest import KplOpenWfpJmiwareEditWareRequest
from third_sdk.jd.api.rest.KplOpenReportUploadRequest import KplOpenReportUploadRequest
from third_sdk.jd.api.rest.KplOpenAlphaHandleventRequest import KplOpenAlphaHandleventRequest
from third_sdk.jd.api.rest.KeplerOrderGetordertrackRequest import KeplerOrderGetordertrackRequest
from third_sdk.jd.api.rest.UnionOpenOrderAgentQueryRequest import UnionOpenOrderAgentQueryRequest
from third_sdk.jd.api.rest.KeplerTradeGetstockRequest import KeplerTradeGetstockRequest
from third_sdk.jd.api.rest.KplOpenMigumusicUnbinddeviceRequest import KplOpenMigumusicUnbinddeviceRequest
from third_sdk.jd.api.rest.KplOpenYaoMultipriceUpdateRequest import KplOpenYaoMultipriceUpdateRequest
from third_sdk.jd.api.rest.KplOpenShopGoodsListRequest import KplOpenShopGoodsListRequest
from third_sdk.jd.api.rest.KplOpenYaoShelfstateBatchupdateRequest import KplOpenYaoShelfstateBatchupdateRequest
from third_sdk.jd.api.rest.UnionOpenOrderRowQueryRequest import UnionOpenOrderRowQueryRequest
from third_sdk.jd.api.rest.KeplerOrderCancelorderRequest import KeplerOrderCancelorderRequest
from third_sdk.jd.api.rest.KeplerSettledAftermarketQueryservicepageRequest import KeplerSettledAftermarketQueryservicepageRequest
from third_sdk.jd.api.rest.KeplerSettledAftermarketQueryservicedetailRequest import KeplerSettledAftermarketQueryservicedetailRequest
from third_sdk.jd.api.rest.KplOpenWfpVscVerifiedNotifyRequest import KplOpenWfpVscVerifiedNotifyRequest
from third_sdk.jd.api.rest.KplOpenCommentCommentlistRequest import KplOpenCommentCommentlistRequest
from third_sdk.jd.api.rest.KplOpenTradeGetorderrefundRequest import KplOpenTradeGetorderrefundRequest
from third_sdk.jd.api.rest.KplOpenWfpVscMakeCertCallbackRequest import KplOpenWfpVscMakeCertCallbackRequest
from third_sdk.jd.api.rest.KplOpenAlphaConfigAddrsgetRequest import KplOpenAlphaConfigAddrsgetRequest
from third_sdk.jd.api.rest.KplOpenWfpVscPreviewRequest import KplOpenWfpVscPreviewRequest
from third_sdk.jd.api.rest.UnionOpenSellingOrderRowQueryRequest import UnionOpenSellingOrderRowQueryRequest
from third_sdk.jd.api.rest.UnionOpenGoodsLinkQueryRequest import UnionOpenGoodsLinkQueryRequest
from third_sdk.jd.api.rest.InvoiceWaybillRequest import InvoiceWaybillRequest
from third_sdk.jd.api.rest.OrderJdOrderIDByThridOrderIDQueryRequest import OrderJdOrderIDByThridOrderIDQueryRequest
from third_sdk.jd.api.rest.KplOpenAftersaleOrderidRequest import KplOpenAftersaleOrderidRequest
from third_sdk.jd.api.rest.KplOpenAlphaHandleRequest import KplOpenAlphaHandleRequest
from third_sdk.jd.api.rest.KplOpenRegularPlanQueryplancountRequest import KplOpenRegularPlanQueryplancountRequest
from third_sdk.jd.api.rest.KplOpenRegularPlanCompletedorderRequest import KplOpenRegularPlanCompletedorderRequest
from third_sdk.jd.api.rest.KplOpenSkuQueryinfoRequest import KplOpenSkuQueryinfoRequest
from third_sdk.jd.api.rest.KeplerXuanpinSearchSkuRequest import KeplerXuanpinSearchSkuRequest
from third_sdk.jd.api.rest.KplOpenJdrepairSaveaddressRequest import KplOpenJdrepairSaveaddressRequest
from third_sdk.jd.api.rest.KplOpenRegularPlanCancleplanRequest import KplOpenRegularPlanCancleplanRequest
from third_sdk.jd.api.rest.KplOpenYaoOrdersyncListRequest import KplOpenYaoOrdersyncListRequest
from third_sdk.jd.api.rest.KeplerXuanpinSearchSkuRequest import KeplerXuanpinSearchSkuRequest
from third_sdk.jd.api.rest.MessageGetRequest import MessageGetRequest
from third_sdk.jd.api.rest.AfterSaleServiceListPageQueryRequest import AfterSaleServiceListPageQueryRequest
from third_sdk.jd.api.rest.KplOpenTradeMasterGetcouponlistRequest import KplOpenTradeMasterGetcouponlistRequest
from third_sdk.jd.api.rest.KeplerXuanpinGetpkglistRequest import KeplerXuanpinGetpkglistRequest
from third_sdk.jd.api.rest.KeplerXuanpinSearchSkuByCategoryRequest import KeplerXuanpinSearchSkuByCategoryRequest
from third_sdk.jd.api.rest.NewWareBaseproductGetRequest import NewWareBaseproductGetRequest
from third_sdk.jd.api.rest.UnionOpenStatisticsRedpacketQueryRequest import UnionOpenStatisticsRedpacketQueryRequest
from third_sdk.jd.api.rest.BizProductGetSimilarSkuRequest import BizProductGetSimilarSkuRequest
from third_sdk.jd.api.rest.KplOpenXdpSoaGetSessionIdRequest import KplOpenXdpSoaGetSessionIdRequest
from third_sdk.jd.api.rest.KplOpenItemFindcanusecouponsRequest import KplOpenItemFindcanusecouponsRequest
from third_sdk.jd.api.rest.ProductDetailQueryRequest import ProductDetailQueryRequest
from third_sdk.jd.api.rest.KplOpenRankInfoGatherServiceRequest import KplOpenRankInfoGatherServiceRequest
from third_sdk.jd.api.rest.UnionOpenActivityRecommendQueryRequest import UnionOpenActivityRecommendQueryRequest
from third_sdk.jd.api.rest.UnionOpenCouponGiftStopRequest import UnionOpenCouponGiftStopRequest
from third_sdk.jd.api.rest.NewWareBaseproductGetRequest import NewWareBaseproductGetRequest
from third_sdk.jd.api.rest.KeplerYaoWareStockUpdateRequest import KeplerYaoWareStockUpdateRequest
from third_sdk.jd.api.rest.KeplerItemQuerybigfieldconvertskuRequest import KeplerItemQuerybigfieldconvertskuRequest
from third_sdk.jd.api.rest.KplOpenYaoOrdersyncUpdatestateRequest import KplOpenYaoOrdersyncUpdatestateRequest
from third_sdk.jd.api.rest.NewWareMobilebigfieldGetRequest import NewWareMobilebigfieldGetRequest
from third_sdk.jd.api.rest.KplOpenYaoPropertyUpdateRequest import KplOpenYaoPropertyUpdateRequest
from third_sdk.jd.api.rest.KplOpenItemFindjoinactivesRequest import KplOpenItemFindjoinactivesRequest
from third_sdk.jd.api.rest.KeplerYaoWarePriceUpdateRequest import KeplerYaoWarePriceUpdateRequest
from third_sdk.jd.api.rest.KplOpenPromiseDosConfigRequest import KplOpenPromiseDosConfigRequest
from third_sdk.jd.api.rest.KplOpenAlphaGetconfigurewithloginRequest import KplOpenAlphaGetconfigurewithloginRequest
from third_sdk.jd.api.rest.ProductSkuQueryRequest import ProductSkuQueryRequest
from third_sdk.jd.api.rest.KplOpenRegularPlanQueryplanlistnewRequest import KplOpenRegularPlanQueryplanlistnewRequest
from third_sdk.jd.api.rest.OpenOrderGetorderlistRequest import OpenOrderGetorderlistRequest
from third_sdk.jd.api.rest.UnionOpenCouponGiftGetRequest import UnionOpenCouponGiftGetRequest
from third_sdk.jd.api.rest.WareProductCatelogyListGetRequest import WareProductCatelogyListGetRequest
from third_sdk.jd.api.rest.UnionOpenStatisticsGiftcouponQueryRequest import UnionOpenStatisticsGiftcouponQueryRequest
from third_sdk.jd.api.rest.ProductCommentSummarysQueryRequest import ProductCommentSummarysQueryRequest
from third_sdk.jd.api.rest.AfterSaleWareReturnJdCompQueryRequest import AfterSaleWareReturnJdCompQueryRequest
from third_sdk.jd.api.rest.KplOpenXuanpinSearchgoodsRequest import KplOpenXuanpinSearchgoodsRequest
from third_sdk.jd.api.rest.OrderJdOrderQueryRequest import OrderJdOrderQueryRequest
from third_sdk.jd.api.rest.BizProductGetcategoryRequest import BizProductGetcategoryRequest
from third_sdk.jd.api.rest.KplOpenMigumusicChannelkeyRequest import KplOpenMigumusicChannelkeyRequest
from third_sdk.jd.api.rest.UnionOpenSellingPromotionGetRequest import UnionOpenSellingPromotionGetRequest
from third_sdk.jd.api.rest.KplOpenPolcenterSubscribeorderRequest import KplOpenPolcenterSubscribeorderRequest
from third_sdk.jd.api.rest.KeplerOrderGetorderdetailRequest import KeplerOrderGetorderdetailRequest
from third_sdk.jd.api.rest.KplOpenPopEnsuregettinggoodsRequest import KplOpenPopEnsuregettinggoodsRequest
from third_sdk.jd.api.rest.PriceBalanceQueryRequest import PriceBalanceQueryRequest
from third_sdk.jd.api.rest.UnionOpenPromotionParseRequest import UnionOpenPromotionParseRequest
from third_sdk.jd.api.rest.KplOpenPolcenterGetexttraceRequest import KplOpenPolcenterGetexttraceRequest
from third_sdk.jd.api.rest.KeplerXuanpinSkuPromotionBatchRequest import KeplerXuanpinSkuPromotionBatchRequest
from third_sdk.jd.api.rest.KplOpenPolcenterUnsubscribemobileRequest import KplOpenPolcenterUnsubscribemobileRequest
from third_sdk.jd.api.rest.KeplerTradeSubmitRequest import KeplerTradeSubmitRequest
from third_sdk.jd.api.rest.KplOpenTradeMasterUsecouponRequest import KplOpenTradeMasterUsecouponRequest
from third_sdk.jd.api.rest.KplOpenBatchConvertCpslinkRequest import KplOpenBatchConvertCpslinkRequest
from third_sdk.jd.api.rest.KplOpenClientGetunplRequest import KplOpenClientGetunplRequest
from third_sdk.jd.api.rest.KplOpenCpsConvertKeplerurlRequest import KplOpenCpsConvertKeplerurlRequest
from third_sdk.jd.api.rest.AddressAllProvincesQueryRequest import AddressAllProvincesQueryRequest
from third_sdk.jd.api.rest.KplOpenAftermarketRefundRequest import KplOpenAftermarketRefundRequest
from third_sdk.jd.api.rest.PopOrderGetmobilelistRequest import PopOrderGetmobilelistRequest
from third_sdk.jd.api.rest.OrderOrderTrackQueryRequest import OrderOrderTrackQueryRequest
from third_sdk.jd.api.rest.ProductSkuGiftQueryRequest import ProductSkuGiftQueryRequest
from third_sdk.jd.api.rest.UnionOpenGoodsBigfieldQueryRequest import UnionOpenGoodsBigfieldQueryRequest
from third_sdk.jd.api.rest.ProductSkuImageQueryRequest import ProductSkuImageQueryRequest
from third_sdk.jd.api.rest.KplOpenAlphashoppingconfSaveinfoRequest import KplOpenAlphashoppingconfSaveinfoRequest
from third_sdk.jd.api.rest.KeplerSkuProductServiceRequest import KeplerSkuProductServiceRequest
from third_sdk.jd.api.rest.ProductSkuCheckRequest import ProductSkuCheckRequest
from third_sdk.jd.api.rest.KplOpenQuerypingpouGetcpsskubypageRequest import KplOpenQuerypingpouGetcpsskubypageRequest
from third_sdk.jd.api.rest.KplOpenUnionSearchByelitedRequest import KplOpenUnionSearchByelitedRequest
from third_sdk.jd.api.rest.KplOpenPromotionPidurlconvertRequest import KplOpenPromotionPidurlconvertRequest
from third_sdk.jd.api.rest.KplOpenXunpinSearchCouponRequest import KplOpenXunpinSearchCouponRequest
from third_sdk.jd.api.rest.KplOpenItemGetmobilewarestyleandjsbywareidRequest import KplOpenItemGetmobilewarestyleandjsbywareidRequest
from third_sdk.jd.api.rest.AfterSaleCustomerExpectCompQueryRequest import AfterSaleCustomerExpectCompQueryRequest
from third_sdk.jd.api.rest.KplOpenItemGetwarestyleandjsbywareidRequest import KplOpenItemGetwarestyleandjsbywareidRequest
from third_sdk.jd.api.rest.BizProductGetSkuByPageRequest import BizProductGetSkuByPageRequest
from third_sdk.jd.api.rest.OrderDoPayRequest import OrderDoPayRequest
from third_sdk.jd.api.rest.OrderCheckRefuseOrderQueryRequest import OrderCheckRefuseOrderQueryRequest
from third_sdk.jd.api.rest.KplOpenNosecretpayClosesignRequest import KplOpenNosecretpayClosesignRequest
from third_sdk.jd.api.rest.KplOpenItemQuerybookbigfieldRequest import KplOpenItemQuerybookbigfieldRequest
from third_sdk.jd.api.rest.AfterSaleAfsApplyCreateRequest import AfterSaleAfsApplyCreateRequest
from third_sdk.jd.api.rest.WareProductbigfieldGetRequest import WareProductbigfieldGetRequest
from third_sdk.jd.api.rest.OrderCheckDlokOrderQueryRequest import OrderCheckDlokOrderQueryRequest
from third_sdk.jd.api.rest.KplOpenNosecretpaySavetokenRequest import KplOpenNosecretpaySavetokenRequest
from third_sdk.jd.api.rest.KeplerOrderDefrayRequest import KeplerOrderDefrayRequest
from third_sdk.jd.api.rest.KplOpenAreaCheckareaRequest import KplOpenAreaCheckareaRequest
from third_sdk.jd.api.rest.UnionOpenExtraDeliverymanValidateRequest import UnionOpenExtraDeliverymanValidateRequest
from third_sdk.jd.api.rest.KplOpenNosecretpaySavesignedRequest import KplOpenNosecretpaySavesignedRequest
from third_sdk.jd.api.rest.BizProductGetcategorysRequest import BizProductGetcategorysRequest
from third_sdk.jd.api.rest.KplOpenSeckillKeplerqbRequest import KplOpenSeckillKeplerqbRequest
from third_sdk.jd.api.rest.AfterSaleSendSkuUpdateRequest import AfterSaleSendSkuUpdateRequest
from third_sdk.jd.api.rest.KplOpenKeplerQuerySkudescriptionRequest import KplOpenKeplerQuerySkudescriptionRequest
from third_sdk.jd.api.rest.OrderOccupyStockConfirmRequest import OrderOccupyStockConfirmRequest
from third_sdk.jd.api.rest.OrderCancelorderRequest import OrderCancelorderRequest
from third_sdk.jd.api.rest.KplOpenNbdMedicineGetricendtockRequest import KplOpenNbdMedicineGetricendtockRequest
from third_sdk.jd.api.rest.MessageDelRequest import MessageDelRequest
from third_sdk.jd.api.rest.KeplerXuanpinGetskuidlistRequest import KeplerXuanpinGetskuidlistRequest
from third_sdk.jd.api.rest.ProductBaseQueryRequest import ProductBaseQueryRequest
from third_sdk.jd.api.rest.UnionOpenStatisticsActivityBonusQueryRequest import UnionOpenStatisticsActivityBonusQueryRequest
from third_sdk.jd.api.rest.ProductYanbaoSkuQueryRequest import ProductYanbaoSkuQueryRequest
from third_sdk.jd.api.rest.OrderFreightGetRequest import OrderFreightGetRequest
from third_sdk.jd.api.rest.OrderPromiseCalendarGetRequest import OrderPromiseCalendarGetRequest
from third_sdk.jd.api.rest.UnionOpenSettleQueryRequest import UnionOpenSettleQueryRequest
from third_sdk.jd.api.rest.KplOpenCouponSearchSkuRequest import KplOpenCouponSearchSkuRequest
from third_sdk.jd.api.rest.StockForListBatgetRequest import StockForListBatgetRequest
from third_sdk.jd.api.rest.UnionOpenStatisticsGoodsSalesQueryRequest import UnionOpenStatisticsGoodsSalesQueryRequest
from third_sdk.jd.api.rest.JosSecretApiReportGetRequest import JosSecretApiReportGetRequest
from third_sdk.jd.api.rest.KplOpenInvoiceQuerythrapplynoRequest import KplOpenInvoiceQuerythrapplynoRequest
from third_sdk.jd.api.rest.KeplerItemGetnologinpromotionRequest import KeplerItemGetnologinpromotionRequest
from third_sdk.jd.api.rest.AfterSaleServiceDetailInfoQueryRequest import AfterSaleServiceDetailInfoQueryRequest
from third_sdk.jd.api.rest.KplOpenGetnewstockbyidQueryRequest import KplOpenGetnewstockbyidQueryRequest
from third_sdk.jd.api.rest.KplOpenRegularPlanShipmentorderRequest import KplOpenRegularPlanShipmentorderRequest
from third_sdk.jd.api.rest.KplOpenItemFindjoinactivesRequest import KplOpenItemFindjoinactivesRequest
from third_sdk.jd.api.rest.KplOpenNosecretpayGetsignurlRequest import KplOpenNosecretpayGetsignurlRequest
from third_sdk.jd.api.rest.KplOpenSelectjdorderQueryRequest import KplOpenSelectjdorderQueryRequest
from third_sdk.jd.api.rest.PriceJincaiCreditQueryRequest import PriceJincaiCreditQueryRequest
from third_sdk.jd.api.rest.OrderWaybilltrackSearchRequest import OrderWaybilltrackSearchRequest
from third_sdk.jd.api.rest.UnionOpenStatisticsRedpacketAgentQueryRequest import UnionOpenStatisticsRedpacketAgentQueryRequest
from third_sdk.jd.api.rest.ProductIsCodQueryRequest import ProductIsCodQueryRequest
from third_sdk.jd.api.rest.AddressTownsByCountyIdQueryRequest import AddressTownsByCountyIdQueryRequest
from third_sdk.jd.api.rest.KeplerServicePromotionGoodsinfoRequest import KeplerServicePromotionGoodsinfoRequest
from third_sdk.jd.api.rest.AddressCitysByProvinceIdQueryRequest import AddressCitysByProvinceIdQueryRequest
from third_sdk.jd.api.rest.MfaUserUnifiedAuthenticationRequest import MfaUserUnifiedAuthenticationRequest
from third_sdk.jd.api.rest.OrderCheckNewOrderQueryRequest import OrderCheckNewOrderQueryRequest
from third_sdk.jd.api.rest.AddressCountysByCityIdQueryRequest import AddressCountysByCityIdQueryRequest
from third_sdk.jd.api.rest.YjcFgcGetOrderDetailRequest import YjcFgcGetOrderDetailRequest
from third_sdk.jd.api.rest.OpenOrderSplitDeliverNewRequest import OpenOrderSplitDeliverNewRequest
from third_sdk.jd.api.rest.KplOpenShenzhouConfigGetRequest import KplOpenShenzhouConfigGetRequest
from third_sdk.jd.api.rest.KplOpenConfigOauthSaveRequest import KplOpenConfigOauthSaveRequest
from third_sdk.jd.api.rest.WarePriceGetRequest import WarePriceGetRequest
from third_sdk.jd.api.rest.KplOpenDingdongProtocolConvertRequest import KplOpenDingdongProtocolConvertRequest
from third_sdk.jd.api.rest.KplOpenItemQuerystockRequest import KplOpenItemQuerystockRequest
from third_sdk.jd.api.rest.UnionOpenGoodsMaterialQueryRequest import UnionOpenGoodsMaterialQueryRequest
from third_sdk.jd.api.rest.UnionOpenSellingGoodsQueryRequest import UnionOpenSellingGoodsQueryRequest
from third_sdk.jd.api.rest.ProductBaseQueryRequest import ProductBaseQueryRequest
from third_sdk.jd.api.rest.OrderUniteSubmitRequest import OrderUniteSubmitRequest
from third_sdk.jd.api.rest.KplOpenXuanpinSearchSkuRequest import KplOpenXuanpinSearchSkuRequest
from third_sdk.jd.api.rest.UnionOpenOrderSettleQueryRequest import UnionOpenOrderSettleQueryRequest
from third_sdk.jd.api.rest.KplOpenItemQuerybookbasicfieldRequest import KplOpenItemQuerybookbasicfieldRequest
from third_sdk.jd.api.rest.PriceBalanceGetRequest import PriceBalanceGetRequest
from third_sdk.jd.api.rest.KeplerItemQueryskusbycatidRequest import KeplerItemQueryskusbycatidRequest
from third_sdk.jd.api.rest.KeplerItemQuerycategoriesbyfidRequest import KeplerItemQuerycategoriesbyfidRequest
from third_sdk.jd.api.rest.BizAreaGetJDAddressFromAddressRequest import BizAreaGetJDAddressFromAddressRequest
from third_sdk.jd.api.rest.OpenRedInvoiceUploadRequest import OpenRedInvoiceUploadRequest
from third_sdk.jd.api.rest.UnionOpenActivityQueryRequest import UnionOpenActivityQueryRequest
from third_sdk.jd.api.rest.OpenGetSplitOrdersRequest import OpenGetSplitOrdersRequest
from third_sdk.jd.api.rest.UnionOpenActivityBonusQueryRequest import UnionOpenActivityBonusQueryRequest
from third_sdk.jd.api.rest.UnionDoubanBookServiceQueryBookUrlListRequest import UnionDoubanBookServiceQueryBookUrlListRequest
from third_sdk.jd.api.rest.KplOpenXimalayaGetresourceRequest import KplOpenXimalayaGetresourceRequest
from third_sdk.jd.api.rest.KplOpenSkuGetwareinfolistRequest import KplOpenSkuGetwareinfolistRequest
from third_sdk.jd.api.rest.KeplerPushmsgSaveBatchSubBehaviourRequest import KeplerPushmsgSaveBatchSubBehaviourRequest
from third_sdk.jd.api.rest.KeplerPushmsgCreateSubSendTaskRequest import KeplerPushmsgCreateSubSendTaskRequest
from third_sdk.jd.api.rest.UnionOpenOrderBonusQueryRequest import UnionOpenOrderBonusQueryRequest
from third_sdk.jd.api.rest.PopOrderEncryptMobileNumRequest import PopOrderEncryptMobileNumRequest
from third_sdk.jd.api.rest.KeplerSettledAddressGetareabymehodnameRequest import KeplerSettledAddressGetareabymehodnameRequest
from third_sdk.jd.api.rest.KeplerPushmsgSendSingleSubMsgRequest import KeplerPushmsgSendSingleSubMsgRequest
from third_sdk.jd.api.rest.KeplerPushmsgGetBusinessCodeListRequest import KeplerPushmsgGetBusinessCodeListRequest
from third_sdk.jd.api.rest.KeplerPushmsgSendBatchMsgRequest import KeplerPushmsgSendBatchMsgRequest
from third_sdk.jd.api.rest.KeplerPushmsgGetAppConfigTemplateListRequest import KeplerPushmsgGetAppConfigTemplateListRequest
from third_sdk.jd.api.rest.JosMasterKeyGetRequest import JosMasterKeyGetRequest
from third_sdk.jd.api.rest.UnionOpenUserRegisterValidateRequest import UnionOpenUserRegisterValidateRequest
from third_sdk.jd.api.rest.KplOpenAlphaHandleRequest import KplOpenAlphaHandleRequest
from third_sdk.jd.api.rest.UnionOpenPromotionAppletGetRequest import UnionOpenPromotionAppletGetRequest
from third_sdk.jd.api.rest.OpenOrderUpdateOrderStateNewRequest import OpenOrderUpdateOrderStateNewRequest
from third_sdk.jd.api.rest.YjcFgcGetOrderListRequest import YjcFgcGetOrderListRequest
from third_sdk.jd.api.rest.YsdkMemberApplyJsfServiceQueryMemberStatusRequest import YsdkMemberApplyJsfServiceQueryMemberStatusRequest
from third_sdk.jd.api.rest.YjcFgcUpdateOrderStateRequest import YjcFgcUpdateOrderStateRequest
from third_sdk.jd.api.rest.KplOpenSearchAssociationalWordRequest import KplOpenSearchAssociationalWordRequest
from third_sdk.jd.api.rest.WareBookbigfieldGetRequest import WareBookbigfieldGetRequest
from third_sdk.jd.api.rest.WareProductbigfieldGetRequest import WareProductbigfieldGetRequest
from third_sdk.jd.api.rest.UnionOpenGoodsSeckillQueryRequest import UnionOpenGoodsSeckillQueryRequest
from third_sdk.jd.api.rest.UnionOpenUserPidGetRequest import UnionOpenUserPidGetRequest
from third_sdk.jd.api.rest.NewWareMobilebigfieldGetRequest import NewWareMobilebigfieldGetRequest
from third_sdk.jd.api.rest.WareProductimageGetRequest import WareProductimageGetRequest
from third_sdk.jd.api.rest.KplOpenShopinfoSkuRequest import KplOpenShopinfoSkuRequest
from third_sdk.jd.api.rest.NewWareBaseproductGetRequest import NewWareBaseproductGetRequest
from third_sdk.jd.api.rest.UnionOpenCategoryGoodsGetRequest import UnionOpenCategoryGoodsGetRequest
from third_sdk.jd.api.rest.WareBasebookGetRequest import WareBasebookGetRequest
from third_sdk.jd.api.rest.KplOpenItemQuerycommentinfoyskusRequest import KplOpenItemQuerycommentinfoyskusRequest
from third_sdk.jd.api.rest.KplOpenItemQueryusablecouponlistbypageRequest import KplOpenItemQueryusablecouponlistbypageRequest
from third_sdk.jd.api.rest.InvoiceSubmitRequest import InvoiceSubmitRequest
from third_sdk.jd.api.rest.InvoiceQueryRequest import InvoiceQueryRequest
from third_sdk.jd.api.rest.AfterSaleAuditCancelQueryRequest import AfterSaleAuditCancelQueryRequest
from third_sdk.jd.api.rest.AfterSaleAvailableNumberCompQueryRequest import AfterSaleAvailableNumberCompQueryRequest
from third_sdk.jd.api.rest.JosVoucherInfoGetRequest import JosVoucherInfoGetRequest
from third_sdk.jd.api.rest.WareProductsortGetRequest import WareProductsortGetRequest
from third_sdk.jd.api.rest.KplOpenJsfTestRequest import KplOpenJsfTestRequest
from third_sdk.jd.api.rest.NewWareSameproductskuidsQueryRequest import NewWareSameproductskuidsQueryRequest
from third_sdk.jd.api.rest.NewWareProductsortattGetRequest import NewWareProductsortattGetRequest
from third_sdk.jd.api.rest.NewWareProductsafedaysGetRequest import NewWareProductsafedaysGetRequest
from third_sdk.jd.api.rest.NewWareAttributeGroupsQueryRequest import NewWareAttributeGroupsQueryRequest
from third_sdk.jd.api.rest.NewWareAttributesQueryRequest import NewWareAttributesQueryRequest
from third_sdk.jd.api.rest.NewWareAttributeValuesQueryRequest import NewWareAttributeValuesQueryRequest
